VideoStabilizationMode enum

The possible video stabilization modes that can be capturing video.

Inheritance
Available extensions

Values

off → const VideoStabilizationMode

Video stabilization is disabled.

level1 → const VideoStabilizationMode

Least stabilized video stabilization mode with the least latency.

level2 → const VideoStabilizationMode

More stabilized video with more latency.

level3 → const VideoStabilizationMode

Most stabilized video with the most latency.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VideoStabilizationMode>
A constant List of the values in this enum, in order of their declaration.